# MessageRole


## Enum

* `DEVELOPER` (value: `'developer'`)

* `SYSTEM` (value: `'system'`)

* `USER` (value: `'user'`)

* `ASSISTANT` (value: `'assistant'`)

* `TOOL` (value: `'tool'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


